[Bf-extensions-cvs] SVN commit: /data/svn/bf-extensions [547] contrib/py/scripts/addons/ image_to_planes.py:

Florian Meyer florianfelix at web.de
Sun Apr 4 10:23:45 CEST 2010


Revision: 547
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-extensions&revision=547
Author:   testscreenings
Date:     2010-04-04 10:23:45 +0200 (Sun, 04 Apr 2010)

Log Message:
-----------


Modified Paths:
--------------
    contrib/py/scripts/addons/image_to_planes.py

Modified: contrib/py/scripts/addons/image_to_planes.py
===================================================================
--- contrib/py/scripts/addons/image_to_planes.py	2010-04-04 06:39:33 UTC (rev 546)
+++ contrib/py/scripts/addons/image_to_planes.py	2010-04-04 08:23:45 UTC (rev 547)
@@ -55,11 +55,11 @@
     'author': 'Florian Meyer (testscreenings)',
     'version': '0.6',
     'blender': (2, 5, 2),
-    'location': 'View3D > Import Images as Planes',
+    'location': 'View3D > Add Mesh',
     'url': '',
     'description': 'Imports images and creates planes \
 with the appropiate aspect ratio',
-    'category': 'Object'}
+    'category': 'Add Mesh'}
 
 ##############################################################################
 ##############################################################################
@@ -241,7 +241,7 @@
 #########################################
 
 def mapget(self):
     """custom property of the planesFromImages addon"""
     mapping = []
     mapping.append(self.shadeless)
     mapping.append(self.transparency)
@@ -354,9 +354,9 @@
 #################       O P E R A T O R        ###############################
 ##############################################################################
 
-class planesFromImages(bpy.types.Operator):
+class image_to_planes(bpy.types.Operator):
     ''''''
-    bl_idname = "mesh.planesFromImages"
+    bl_idname = "mesh.image_to_planes"
     bl_label = "Import Images as Planes"
     bl_description = "Create plane(s) from images"
     bl_options = {'REGISTER', 'UNDO'}
@@ -437,16 +437,16 @@
 
 #### Registering ####
 
-menu_func = (lambda self, context: self.layout.operator(planesFromImages.bl_idname,
+menu_func = (lambda self, context: self.layout.operator(image_to_planes.bl_idname,
                                         text="Imageplanes", icon='PLUGIN'))
 
 def register():
-    bpy.types.register(planesFromImages)
+    bpy.types.register(image_to_planes)
     bpy.types.INFO_MT_mesh_add.append(menu_func)
 
 
 def unregister():
-    bpy.types.unregister(planesFromImages)
+    bpy.types.unregister(image_to_planes)
     bpy.types.INFO_MT_mesh_add.remove(menu_func)
 
 
@@ -241,7 +241,7 @@
 
 def mapget(self):
-    """custom property of the planesFromImages addon"""
+    """custom property of the image_to_planes addon"""
     mapping = []
     mapping.append(self.shadeless)




More information about the Bf-extensions-cvs mailing list